django_geopostcodes.managers — django-geopostcodes 0.1.0 documentation

# django_geopostcodes.managers

Django model managers for django-geopostcodes.

class `django_geopostcodes.managers.` `LocalityManager`

  Bases: `django.db.models.manager.ManagerFromLocalityQuerySet`

  Overrides Manager to return Geographic QuerySets.

  `use_for_related_fields` = True

class `django_geopostcodes.managers.` `LocalityQuerySet`(model=None, query=None, using=None, hints=None)

  Bases: `django.contrib.gis.db.models.query.GeoQuerySet`

  Locality QuerySet.

  `anything`(lookup_type, value, fields=['country', 'region1', 'region2', 'region3', 'region4', 'locality', 'postcode', 'suburb'])
  `anything_contains`(value, fields=['country', 'region1', 'region2', 'region3', 'region4', 'locality', 'postcode', 'suburb'])
  `anything_endswith`(value, fields=['country', 'region1', 'region2', 'region3', 'region4', 'locality', 'postcode', 'suburb'])
  `anything_exact`(value, fields=['country', 'region1', 'region2', 'region3', 'region4', 'locality', 'postcode', 'suburb'])
  `anything_fields` = ['country', 'region1', 'region2', 'region3', 'region4', 'locality', 'postcode', 'suburb']
  `anything_icontains`(value, fields=['country', 'region1', 'region2', 'region3', 'region4', 'locality', 'postcode', 'suburb'])
  `anything_iendswith`(value, fields=['country', 'region1', 'region2', 'region3', 'region4', 'locality', 'postcode', 'suburb'])
  `anything_iexact`(value, fields=['country', 'region1', 'region2', 'region3', 'region4', 'locality', 'postcode', 'suburb'])
  `anything_istartswith`(value, fields=['country', 'region1', 'region2', 'region3', 'region4', 'locality', 'postcode', 'suburb'])
  `anything_startswith`(value, fields=['country', 'region1', 'region2', 'region3', 'region4', 'locality', 'postcode', 'suburb'])